@@ -1,6 +1,6 @@
 /* metar.c -- metar decoder
-   $Id: main.c,v 1.4 2005/04/08 06:57:56 kees-guest Exp $
-   Copyright 2004 Kees Leune <kees@leune.org>
+   $Id: main.c,v 1.8 2005/08/07 13:25:15 kees-guest Exp $
+   Copyright 2004,2005 Kees Leune <kees@leune.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ char *strupc(char *line) {
 
 /* show brief usage info */
 void usage(char *name) {
-	printf("$Id: main.c,v 1.4 2005/04/08 06:57:56 kees-guest Exp $\n");
+	printf("$Id: main.c,v 1.8 2005/08/07 13:25:15 kees-guest Exp $\n");
 	printf("Usage: %s options\n", name);
 	printf("Options\n");
 	printf("   -d        decode metar\n");
@@ -102,11 +102,16 @@ void decode_Metar(metar_t metar) {
 
 	printf("Station       : %s\n", metar.station);
 	printf("Day           : %i\n", metar.day);
-	printf("Time          : %i UTC\n", metar.time);
+	printf("Time          : %02i:%02i UTC\n", metar.time/100, metar.time%100);
 	if (metar.winddir == -1) {
 		printf("Wind direction: Variable\n");
 	} else {
-		printf("Wind direction: %i\n", metar.winddir);
+		static const char *winddirs[] = {
+			"N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE",
+			"S", "SSW", "SW", "WSW", "W", "WNW", "NW", "NNW"
+	};
+	int i = ((metar.winddir * 4 + 45) / 90) % 16;
+	printf("Wind direction: %i (%s)\n", metar.winddir, winddirs[i]);
 	}
 	printf("Wind speed    : %i %s\n", metar.windstr, metar.windunit);
 	printf("Wind gust     : %i %s\n", metar.windgust, metar.windunit);
